@@ -1,4 +1,5 @@
 import pulp, type_enforced
+from pprint import pprint
 from .utils import Error
 
 
@@ -7,8 +8,8 @@ class ModelUtils(Error):
     @staticmethod
     def variable(
         name: str,
-        lowBound: [float, int, type(None)] = None,
-        upBound: [float, int, type(None)] = None,
+        lowBound: [float, int, None] = None,
+        upBound: [float, int, None] = None,
         cat: str = "Continuous",
     ):
         """
@@ -59,7 +60,7 @@ class ModelUtils(Error):
 
 @type_enforced.Enforcer
 class Model(ModelUtils):
-    def __init__(self, name: str, sense: [str, type(None)]):
+    def __init__(self, name: str, sense: [str, None]):
         """
         Initialize a new optimization model object.
 
@@ -124,7 +125,7 @@ class Model(ModelUtils):
         # Update the __objective_added__ validation attribute
         self.__objective_added__ = True
 
-    def add_constraint(self, fn, name: [str, type(None)] = None):
+    def add_constraint(self, fn, name: [str, None] = None):
         """
         Add a constraint function to the current model object. Each model can have unlimited constraints.
 
@@ -132,7 +133,7 @@ class Model(ModelUtils):
 
         - `fn`:
             - Type: function
-            - What: The pythonic version of the objective function
+            - What: The pythonic version of a constraint function
             - Note: This function should have pythonic [comparison operators](https://docs.python.org/3/reference/expressions.html#comparison)
 
         Optional:
@@ -275,6 +276,43 @@ class Model(ModelUtils):
         """
         Returns the current model formulation as a string in a human readable form.
 
-        Note: This aggregate variables where possible such that `variable_1*2 + variable_1*1` => `variable_1*3`
+        Note: This aggregates variables where possible such that
+
+        - `variable_1*2 + variable_1*1` => `variable_1*3`
         """
         return str(self.model)
+
+    def show_formulation(self):
+        """
+        Prints the model formulation generated by self.get_formulation()
+        """
+        print(self.get_formulation())
+
+    def get_outputs(self):
+        """
+        Returns a solved model's outputs.
+
+        Note: A model must be solved before getting these outputs
+        """
+        if not self.__solved__:
+            self.exception(
+                "The current model must be solved before getting outputs."
+            )
+        return self.outputs
+
+    def show_outputs(self, pretty=True):
+        """
+        Shows a solved models outputs in the terminal. (using self.get_outputs())
+
+        Optional:
+
+            - `pretty`:
+                - Type: bool
+                - What: Show the outputs in a pretty format
+                - Default: True
+        """
+        outputs = self.get_outputs()
+        if pretty:
+            pprint(outputs)
+        else:
+            print(output)
